@@ -465,10 +465,10 @@ def signal_correction_algebric(signal_data,S_matrix, R_matrix, T_matrix,  mesh_p
 
     #cupy Version (CUDA kernel)
     #compute scalar product
-    mult_res=(1/c.value)*cupy.matmul(S_matrix,R_matrix)
+    mult_res=(1/c.value)*cupy.matmul(cupy.array(S_matrix),cupy.array(R_matrix))
 
     #compute time delay
-    result= T_matrix-mult_res
+    result= cupy.array(T_matrix)-mult_res
 
     #result have same size than T_matrix (360*180*pres)*time
     return result
